<?php
/**
* @version 1.0.1
* @package Easy Pay PayPal Module 
* @copyright Copyright &copy; 2007, OCS Software Solutions, in partnership with Ninjoomla.com
* @author Ozgur Cem Sen
* @email cms@ocssoftwaresolutions.com
* @link http://www.ninjoomla.com || http://www.ocsoftwaresolutions.com || http://www.ocszone.com
* @license http://www.gnu.org/licenses/gpl.html GNU/GPL .
*/


/**
 * The parameters are pretty much "prefix-coded".
 * show_  parameters are basically boolean values to determine the preceeding setting to be displayed or not. 
 * gui_ parameters are PayPal specific parameters which can be shown on our site's frontend
 * config_ parameters are used for handling some business logic in the code.
 * The rest can be sent to PayPal as hidden form values with the default values set in Administration 
 * 
 */

defined('_VALID_MOS') or die('Direct Access to this location is not allowed.');

//We will use this global to get the site info so we can put the css/js tags
//into the header area.
global $mosConfig_live_site;


/**
 * A Test notification will be displayed next to title to warn users...
 */
$test_notification = "";

/**
 * module parameters read into a class
 */
$params = mosParseParams( $module->params );



/**
 * CSS file to render Easy Pay PayPal
 */
$css_file = $mosConfig_live_site . "/modules/mod_easypaypaypal/".$params->config_css_file;
/**
 * CSS class suffices for the multiple instances
 */
$css_suffix = $params->config_css_suffix;

/**
 * PayPal account and server used in the form
 */
if ($params->config_is_live == 0) {
	$params->business = $params->config_business_test;
	$params->config_URL = "https://www.sandbox.paypal.com/cgi-bin/webscr";
	$test_notification = "<strong>TEST</strong>";
}
else {
	$params->business = $params->config_business;
	$params->config_URL = "https://www.paypal.com/cgi-bin/webscr";
	$test_notification = "";
}

/**
 * so unique tag ids will be used across the form. 
 */
$tagid = rand();      

/**
 * if custom image is used for the form, assign it to the gui_paypal_image. 
 * Just to make code a bit clearer down below.
 */
if (strlen($params->gui_paypal_image_custom)) 
	$params->gui_paypal_image = $params->gui_paypal_image_custom;


$headertag = '<link rel="stylesheet" href="'.$css_file.'" type="text/css"/>'."\n";

$buffer = ob_get_contents();
$hdrPos = strpos ($buffer, '</head>');
$buffer = substr ($buffer, 0, $hdrPos) . "\n$headertag\n". substr($buffer, $hdrPos);
ob_clean();
echo $buffer;

?>
<!--// Easy Pay PayPal Module for Mambo, OCS Software Solutions, (c) 2007 //-->  
<div class="easypaypaypal<?php echo $css_suffix;?>">
	<!--// start of PayPal form //-->
	<form action="<?php echo $params->config_URL; ?>" method="post">

	<?php
	//SET THE TITLE
	if (strlen($params->gui_title)) {
	?>
	    <div class="easypaypaypal-title<?php echo $css_suffix;?>">
	        <?php echo $params->gui_title." ".$test_notification; ?>
	    </div>	
	<?php
	}
	?>

	<?php
	//SHOW THE ITEM NAME
	if ($params->show_item_name) {
	?>
	    <div class="easypaypaypal-item-block<?php echo $css_suffix;?>">
	        <span class="easypaypaypal-item-label<?php echo $css_suffix;?>"><?php echo $params->gui_item_name;?></span>
	    </div>	
	<?php
	}
	?>
	<input type="hidden" name="item_name" value="<?php echo $params->gui_item_name; ?>"/>

	<?php
	//DO WE ALLOW USERS ENTER QUANTITY
	if ($params->show_quantity && $params->undefined_quantity) {
	?>
	    <div class="easypaypaypal-quantity-block<?php echo $css_suffix;?>">
         <label for="easypaypaypal-quantity-editbox<?php echo $tagid;?>">Quantity:</label>
	      <input id="easypaypaypal-quantity-editbox<?php echo $tagid;?>" class="easypaypaypal-quantity-editbox<?php echo $css_suffix;?>" type="text" size="2" name="quantity" value="<?php echo $params->gui_quantity; ?>"/>		  
	    </div>	
	<?php
	}
	else if ($params->undefined_quantity)
	{
	?>
		<input type="hidden" name="quantity" value="<?php echo $params->gui_quantity; ?>"/>
	<?php
	}
	?>

	<?php
	//DO WE ALLOW THE USERS ENTER AMOUNT
	if ($params->show_amount) {
	?>
		<div class="easypaypaypal-amount-block<?php echo $css_suffix;?>">
			<label for="easypaypaypal-amount-editbox<?php echo $tagid;?>">Amount<?php
			if (!$params->show_currency_code) {
				echo " ".$params->gui_currency_code;
			}
			?>:</label>
			<?php
			if ($params->show_amount) {
			?>	
				<input id="easypaypaypal-amount-editbox<?php echo $tagid;?>" class="easypaypaypal-amount-editbox<?php echo $css_suffix;?>" type="text" size="4" name="amount" value="<?php echo $params->gui_amount; ?>"/>		  
			<?php
			}
			?>     
	 </div>

	 <?php
	 	//allow the currency select, only if the amount can be entered on the site. 
		if ($params->show_currency_code) {
		?>	    
			 <div class="easypaypaypal-currency-block<?php echo $css_suffix;?>">
            <label for="easypaypaypal-currency-combobox<?php echo $tagid;?>">Currency:</label>
				  <select id="easypaypaypal-currency-combobox<?php echo $tagid;?>" class="easypaypaypal-currency-combobox<?php echo $css_suffix;?>" name="currency_code">
					<option value="USD" <?php if ($params->gui_currency_code == "USD") echo "SELECTED"?>>U.S. Dollar</option>
					<option value="EUR" <?php if ($params->gui_currency_code == "EUR") echo "SELECTED"?>>Euro</option>
					<option value="GBP" <?php if ($params->gui_currency_code == "GBP") echo "SELECTED"?>>Pound Sterling</option>
					<option value="DKK" <?php if ($params->gui_currency_code == "DKK") echo "SELECTED"?>>Danish Krone</option>
					<option value="NOK" <?php if ($params->gui_currency_code == "NOK") echo "SELECTED"?>>Norwegian Krone</option>
					<option value="SEK" <?php if ($params->gui_currency_code == "SEK") echo "SELECTED"?>>Swedish Krona</option>
					<option value="JPY" <?php if ($params->gui_currency_code == "JPY") echo "SELECTED"?>>Japanese Yen</option>
					<option value="NZD" <?php if ($params->gui_currency_code == "NZD") echo "SELECTED"?>>New Zealand Dollar</option>	
					<option value="SGD" <?php if ($params->gui_currency_code == "SGD") echo "SELECTED"?>>Singapore Dollar</option>
					<option value="HKD" <?php if ($params->gui_currency_code == "HKD") echo "SELECTED"?>>Hong Kong Dollar</option>
					<option value="HUF" <?php if ($params->gui_currency_code == "HUF") echo "SELECTED"?>>Hungarian Forint</option>
					<option value="PLN" <?php if ($params->gui_currency_code == "PLN") echo "SELECTED"?>>Polish Zloty</option>	
				  </select>            
			 </div>
	<?php
		}
	}
	
	if (((int)$params->gui_amount != 0 && (!$params->show_amount))){
	?>
	 <div class="easypaypaypal-amount-block<?php echo $css_suffix;?>">
		<label for="easypaypaypal-amount<?php echo $tagid;?>">Amount:</label>
      <span id="easypaypaypal-amount<?php echo $tagid;?>" class="easypaypaypal-amount<?php echo $css_suffix;?>"><?php echo $params->gui_amount." ".$params->gui_currency_code; ?></span>
	</div>
		<input type="hidden" name="currency_code" value="<?php echo $params->gui_currency_code; ?>"/>
		<input type="hidden" name="amount" value="<?php echo $params->gui_amount; ?>"/>
	<?php
	}
	?>

	<?php //ADD THE PAYPAL IMAGE ?>
    <div class="easypaypaypal-image<?php echo $css_suffix;?>">
		<input type   ="image"
               src    ="<?php echo $mosConfig_live_site."/modules/mod_easypaypaypal/".$params->gui_paypal_image?>"
               name   ="submit"
               alt    ="<?php echo $params->gui_title; ?>"
               title  ="<?php echo $params->gui_title; ?>" />
    </div>
    
    <?php 
    	//the rest of the parms are hidden. simply dump them.
		foreach ($params as $param => $value){
			
			if ((substr($param, 0, 4) != "gui_") 
				&& (substr($param, 0, 5) != "show_")
				&& (substr($param, 0, 7) != "config_")
				&& ($param != "Classes")) {				
					
				echo "<input type=\"hidden\" name=\"". $param ."\" value=\"". $value ."\"/>\n\t";
			}
		}
    ?>
	</form> <!--// end of PayPal form //--> 
</div>
<!--// end of Easy Pay PayPal Module, OCS Software Solutions, (c) 2007 //-->  

